@@ -225,7 +225,7 @@ class DDLParser(
             raise DDLParserError(f"Unknown statement at {p}")
 
 
-def parse_from_file(file_path: str, parser_settings: Optional[dict]={}, **kwargs) -> List[Dict]:
+def parse_from_file(file_path: str, parser_settings: Optional[dict] = None, **kwargs) -> List[Dict]:
     """get useful data from ddl"""
     with open(file_path, "r") as df:
-        return DDLParser(df.read(), **parser_settings).run(file_path=file_path, **kwargs)
+        return DDLParser(df.read(), **(parser_settings or {})).run(file_path=file_path, **kwargs)
